==> mediawiki-1.28.0-1-any.pkg.tar.xz: usr/share/webapps/mediawiki/extensions/Nuke/Nuke.alias.php <==
<?php
/**
 * Aliases for Special:Nuke
 *
 * @file
 * @ingroup Extensions
 */
// @codingStandardsIgnoreFile

$specialPageAliases = array();

/** English (English) */
$specialPageAliases['en'] = array(
	'Nuke' => array( 'Nuke' ),
);

/** Arabic (العربية) */
$specialPageAliases['ar'] = array(
	'Nuke' => array( 'حذف_كمي' ),
);

/** Egyptian Arabic (مصرى) */
$specialPageAliases['arz'] = array(
	'Nuke' => array( 'مسح_كامل' ),
);

/** Avaric (авар) */
$specialPageAliases['av'] = array(
	'Nuke' => array( 'Множественное_удаление' ),
);

/** Bashkir (башҡортса) */
$specialPageAliases['ba'] = array(
	'Nuke' => array( 'Nuke' ),
);

/** Belarusian (Taraškievica orthography) (беларуская (тарашкевіца)‎) */
$specialPageAliases['be-tarask'] = array(
	'Nuke' => array( 'Масавае_выдаленьне' ),
);

/** Western Balochi (بلوچی رخشانی) */
$specialPageAliases['bgn'] = array(
	'Nuke' => array( 'دسته_جمین_پاک_کورتین' ),
);

/** Banjar (Bahasa Banjar) */
$specialPageAliases['bjn'] = array(
	'Nuke' => array( 'Nuklir' ),
);

/** Chechen (нохчийн) */
$specialPageAliases['ce'] = array(
	'Nuke' => array( 'Дуккха_дӀаяхар' ),
);

/** Czech (česky) */
$specialPageAliases['cs'] = array(
	'Nuke' => array( 'Hromadné_mazání', 'Zničit', 'Zničení' ),
);

/** German (Deutsch) */
$specialPageAliases['de'] = array(
	'Nuke' => array( 'Massenlöschung' ),
);

/** Zazaki (Zazaki) */
$specialPageAliases['diq'] = array(
	'Nuke' => array( 'Pıperne' ),
);

/** Lower Sorbian (dolnoserbski) */
$specialPageAliases['dsb'] = array(
	'Nuke' => array( 'Wulašowanje_z_kopicami' ),
);

/** Spanish (español) */
$specialPageAliases['es'] = array(
	'Nuke' => array( 'BorradoMasivo', 'Borrado_en_masa', 'Borrado_masivo' ),
);

/** Estonian (eesti) */
$specialPageAliases['et'] = array(
	'Nuke' => array( 'Lauskustutamine' ),
);

/** Persian (فارسی) */
$specialPageAliases['fa'] = array(
	'Nuke' => array( 'حذف_دسته‌جمعی' ),
);

/** Finnish (suomi) */
$specialPageAliases['fi'] = array(
	'Nuke' => array( 'Massapoista' ),
);

/** Galician (galego) */
$specialPageAliases['gl'] = array(
	'Nuke' => array( 'Eliminar_en_masa' ),
);

/** Swiss German (Alemannisch) */
$specialPageAliases['gsw'] = array(
	'Nuke' => array( 'Masseleschig' ),
);

/** Hawaiian (Hawai`i) */
$specialPageAliases['haw'] = array(
	'Nuke' => array( 'Luku' ),
);

/** Hebrew (עברית) */
$specialPageAliases['he'] = array(
	'Nuke' => array( 'מחיקה_מרובה' ),
);

/** Hindi (हिन्दी) */
$specialPageAliases['hi'] = array(
	'Nuke' => array( 'कई_पृष्ठ_हटाएँ', 'कई_पृष्ठ_हटायें', 'न्यूक' ),
);

/** Upper Sorbian (hornjoserbsce) */
$specialPageAliases['hsb'] = array(
	'Nuke' => array( 'Masowe_wušmórnjenje' ),
);

/** Haitian (Kreyòl ayisyen) */
$specialPageAliases['ht'] = array(
	'Nuke' => array( 'Dechouke' ),
);

/** Hungarian (magyar) */
$specialPageAliases['hu'] = array(
	'Nuke' => array( 'Kiirtás' ),
);

/** Interlingua (interlingua) */
$specialPageAliases['ia'] = array(
	'Nuke' => array( 'Deler_in_massa' ),
);

/** Indonesian (Bahasa Indonesia) */
$specialPageAliases['id'] = array(
	'Nuke' => array( 'Nuklir' ),
);

/** Icelandic (íslenska) */
$specialPageAliases['is'] = array(
	'Nuke' => array( 'Fjöldaeyða' ),
);

/** Italian (italiano) */
$specialPageAliases['it'] = array(
	'Nuke' => array( 'CancellazioneMassiva' ),
);

/** Japanese (日本語) */
$specialPageAliases['ja'] = array(
	'Nuke' => array( 'まとめて削除' ),
);

/** Korean (한국어) */
$specialPageAliases['ko'] = array(
	'Nuke' => array( '문서대량삭제' ),
);

/** Colognian (Ripoarisch) */
$specialPageAliases['ksh'] = array(
	'Nuke' => array( 'Maßesch_Sigge_Fottschmiiße' ),
);

/** Ladino (Ladino) */
$specialPageAliases['lad'] = array(
	'Nuke' => array( 'Bombardea' ),
);

/** Luxembourgish (Lëtzebuergesch) */
$specialPageAliases['lb'] = array(
	'Nuke' => array( 'Masseläschung' ),
);

/** Northern Luri (لۊری شومالی) */
$specialPageAliases['lrc'] = array(
	'Nuke' => array( 'أتومی' ),
);

/** Literary Chinese (文言) */
$specialPageAliases['lzh'] = array(
	'Nuke' => array( '量刪' ),
);

/** Macedonian (македонски) */
$specialPageAliases['mk'] = array(
	'Nuke' => array( 'Нукирање' ),
);

/** Malayalam (മലയാളം) */
$specialPageAliases['ml'] = array(
	'Nuke' => array( 'സർവ്വനാശം' ),
);

/** Malay (Bahasa Melayu) */
$specialPageAliases['ms'] = array(
	'Nuke' => array( 'Hapus_pukal' ),
);

/** Norwegian Bokmål (norsk bokmål) */
$specialPageAliases['nb'] = array(
	'Nuke' => array( 'Massesletting' ),
);

/** Low Saxon (Netherlands) (Nedersaksies) */
$specialPageAliases['nds-nl'] = array(
	'Nuke' => array( 'Massaal_vortdoon' ),
);

/** Dutch (Nederlands) */
$specialPageAliases['nl'] = array(
	'Nuke' => array( 'MassaalVerwijderen' ),
);

/** Norwegian Nynorsk (norsk nynorsk) */
$specialPageAliases['nn'] = array(
	'Nuke' => array( 'Massesletting', 'Masseslett' ),
);

/** Polish (polski) */
$specialPageAliases['pl'] = array(
	'Nuke' => array( 'Masowe_usuwanie' ),
);

/** Portuguese (português) */
$specialPageAliases['pt'] = array(
	'Nuke' => array( 'Eliminar_em_massa' ),
);

/** Brazilian Portuguese (português do Brasil) */
$specialPageAliases['pt-br'] = array(
	'Nuke' => array( 'Eliminar_em_massa' ),
);

/** Russian (русский) */
$specialPageAliases['ru'] = array(
	'Nuke' => array( 'Множественное_удаление' ),
);

/** Sanskrit (संस्कृतम्) */
$specialPageAliases['sa'] = array(
	'Nuke' => array( 'न्यूक' ),
);

/** Sicilian (sicilianu) */
$specialPageAliases['scn'] = array(
	'Nuke' => array( 'CancellazioneMassiva' ),
);

/** Slovak (slovenčina) */
$specialPageAliases['sk'] = array(
	'Nuke' => array( 'Zničenie' ),
);

/** Swedish (svenska) */
$specialPageAliases['sv'] = array(
	'Nuke' => array( 'Massradering' ),
);

/** Tagalog (Tagalog) */
$specialPageAliases['tl'] = array(
	'Nuke' => array( 'Malawakang_pagbura' ),
);

/** Turkish (Türkçe) */
$specialPageAliases['tr'] = array(
	'Nuke' => array( 'Uçur' ),
);

/** Ukrainian (українська) */
$specialPageAliases['uk'] = array(
	'Nuke' => array( 'Масове_вилучення' ),
);

/** Vietnamese (Tiếng Việt) */
$specialPageAliases['vi'] = array(
	'Nuke' => array( 'Xóa_hàng_loạt', 'Xoá_hàng_loạt' ),
);

/** Chinese (中文) */
$specialPageAliases['zh'] = array(
	'Nuke' => array( '大量删除', '大量刪除' ),
);

/** Simplified Chinese (中文（简体）‎) */
$specialPageAliases['zh-hans'] = array(
	'Nuke' => array( '大量删除' ),
);

/** Traditional Chinese (中文（繁體）‎) */
$specialPageAliases['zh-hant'] = array(
	'Nuke' => array( '大量刪除' ),
);

==> mediawiki-1.29.2-1-any.pkg.tar.xz: usr/share/webapps/mediawiki/extensions/Nuke/Nuke.alias.php <==
<?php
/**
 * Aliases for Special:Nuke
 *
 * @file
 * @ingroup Extensions
 */
// @codingStandardsIgnoreFile

$specialPageAliases = array();

/** English (English) */
$specialPageAliases['en'] = array(
	'Nuke' => array( 'Nuke' ),
);

/** Arabic (العربية) */
$specialPageAliases['ar'] = array(
	'Nuke' => array( 'حذف_كمي' ),
);

/** Egyptian Arabic (مصرى) */
$specialPageAliases['arz'] = array(
	'Nuke' => array( 'مسح_كامل' ),
);

/** Avaric (авар) */
$specialPageAliases['av'] = array(
	'Nuke' => array( 'Множественное_удаление' ),
);

/** Bashkir (башҡортса) */
$specialPageAliases['ba'] = array(
	'Nuke' => array( 'Nuke' ),
);

/** Belarusian (Taraškievica orthography) (беларуская (тарашкевіца)‎) */
$specialPageAliases['be-tarask'] = array(
	'Nuke' => array( 'Масавае_выдаленьне' ),
);

/** Western Balochi (بلوچی رخشانی) */
$specialPageAliases['bgn'] = array(
	'Nuke' => array( 'دسته_جمین_پاک_کورتین' ),
);

/** Banjar (Bahasa Banjar) */
$specialPageAliases['bjn'] = array(
	'Nuke' => array( 'Nuklir' ),
);

/** Bengali (বাংলা) */
$specialPageAliases['bn'] = array(
	'Nuke' => array( 'গণ_অপসারণ' ),
);

/** Chechen (нохчийн) */
$specialPageAliases['ce'] = array(
	'Nuke' => array( 'Дуккха_дӀаяхар' ),
);

/** Czech (česky) */
$specialPageAliases['cs'] = array(
	'Nuke' => array( 'Hromadné_mazání', 'Zničit', 'Zničení' ),
);

/** German (Deutsch) */
$specialPageAliases['de'] = array(
	'Nuke' => array( 'Massenlöschung' ),
);

/** Zazaki (Zazaki) */
$specialPageAliases['diq'] = array(
	'Nuke' => array( 'Pıperne' ),
);

/** Lower Sorbian (dolnoserbski) */
$specialPageAliases['dsb'] = array(
	'Nuke' => array( 'Wulašowanje_z_kopicami' ),
);

/** Spanish (español) */
$specialPageAliases['es'] = array(
	'Nuke' => array( 'BorradoMasivo', 'Borrado_en_masa', 'Borrado_masivo' ),
);

/** Estonian (eesti) */
$specialPageAliases['et'] = array(
	'Nuke' => array( 'Lauskustutamine' ),
);

/** Persian (فارسی) */
$specialPageAliases['fa'] = array(
	'Nuke' => array( 'حذف_دسته‌جمعی' ),
);

/** Finnish (suomi) */
$specialPageAliases['fi'] = array(
	'Nuke' => array( 'Massapoista' ),
);

/** Galician (galego) */
$specialPageAliases['gl'] = array(
	'Nuke' => array( 'Eliminar_en_masa' ),
);

/** Swiss German (Alemannisch) */
$specialPageAliases['gsw'] = array(
	'Nuke' => array( 'Masseleschig' ),
);

/** Hawaiian (Hawai`i) */
$specialPageAliases['haw'] = array(
	'Nuke' => array( 'Luku' ),
);

/** Hebrew (עברית) */
$specialPageAliases['he'] = array(
	'Nuke' => array( 'מחיקה_מרובה' ),
);

/** Hindi (हिन्दी) */
$specialPageAliases['hi'] = array(
	'Nuke' => array( 'कई_पृष्ठ_हटाएँ', 'कई_पृष्ठ_हटायें', 'न्यूक' ),
);

/** Upper Sorbian (hornjoserbsce) */
$specialPageAliases['hsb'] = array(
	'Nuke' => array( 'Masowe_wušmórnjenje' ),
);

/** Haitian (Kreyòl ayisyen) */
$specialPageAliases['ht'] = array(
	'Nuke' => array( 'Dechouke' ),
);

/** Hungarian (magyar) */
$specialPageAliases['hu'] = array(
	'Nuke' => array( 'Kiirtás' ),
);

/** Interlingua (interlingua) */
$specialPageAliases['ia'] = array(
	'Nuke' => array( 'Deler_in_massa' ),
);

/** Indonesian (Bahasa Indonesia) */
$specialPageAliases['id'] = array(
	'Nuke' => array( 'Nuklir' ),
);

/** Icelandic (íslenska) */
$specialPageAliases['is'] = array(
	'Nuke' => array( 'Fjöldaeyða' ),
);

/** Italian (italiano) */
$specialPageAliases['it'] = array(
	'Nuke' => array( 'CancellazioneMassiva' ),
);

/** Japanese (日本語) */
$specialPageAliases['ja'] = array(
	'Nuke' => array( 'まとめて削除' ),
);

/** Korean (한국어) */
$specialPageAliases['ko'] = array(
	'Nuke' => array( '문서대량삭제' ),
);

/** Colognian (Ripoarisch) */
$specialPageAliases['ksh'] = array(
	'Nuke' => array( 'Maßesch_Sigge_Fottschmiiße' ),
);

/** Ladino (Ladino) */
$specialPageAliases['lad'] = array(
	'Nuke' => array( 'Bombardea' ),
);

/** Luxembourgish (Lëtzebuergesch) */
$specialPageAliases['lb'] = array(
	'Nuke' => array( 'Masseläschung' ),
);

/** Northern Luri (لۊری شومالی) */
$specialPageAliases['lrc'] = array(
	'Nuke' => array( 'أتومی' ),
);

/** Literary Chinese (文言) */
$specialPageAliases['lzh'] = array(
	'Nuke' => array( '量刪' ),
);

/** Macedonian (македонски) */
$specialPageAliases['mk'] = array(
	'Nuke' => array( 'Нукирање' ),
);

/** Malayalam (മലയാളം) */
$specialPageAliases['ml'] = array(
	'Nuke' => array( 'സർവ്വനാശം' ),
);

/** Malay (Bahasa Melayu) */
$specialPageAliases['ms'] = array(
	'Nuke' => array( 'Hapus_pukal' ),
);

/** Norwegian Bokmål (norsk bokmål) */
$specialPageAliases['nb'] = array(
	'Nuke' => array( 'Massesletting' ),
);

/** Low Saxon (Netherlands) (Nedersaksies) */
$specialPageAliases['nds-nl'] = array(
	'Nuke' => array( 'Massaal_vortdoon' ),
);

/** Dutch (Nederlands) */
$specialPageAliases['nl'] = array(
	'Nuke' => array( 'MassaalVerwijderen' ),
);

/** Norwegian Nynorsk (norsk nynorsk) */
$specialPageAliases['nn'] = array(
	'Nuke' => array( 'Massesletting', 'Masseslett' ),
);

/** Polish (polski) */
$specialPageAliases['pl'] = array(
	'Nuke' => array( 'Masowe_usuwanie' ),
);

/** Portuguese (português) */
$specialPageAliases['pt'] = array(
	'Nuke' => array( 'Eliminar_em_massa' ),
);

/** Brazilian Portuguese (português do Brasil) */
$specialPageAliases['pt-br'] = array(
	'Nuke' => array( 'Eliminar_em_massa' ),
);

/** Russian (русский) */
$specialPageAliases['ru'] = array(
	'Nuke' => array( 'Множественное_удаление' ),
);

/** Sanskrit (संस्कृतम्) */
$specialPageAliases['sa'] = array(
	'Nuke' => array( 'न्यूक' ),
);

/** Sicilian (sicilianu) */
$specialPageAliases['scn'] = array(
	'Nuke' => array( 'CancellazioneMassiva' ),
);

/** Slovak (slovenčina) */
$specialPageAliases['sk'] = array(
	'Nuke' => array( 'Zničenie' ),
);

/** Swedish (svenska) */
$specialPageAliases['sv'] = array(
	'Nuke' => array( 'Massradering' ),
);

/** Tagalog (Tagalog) */
$specialPageAliases['tl'] = array(
	'Nuke' => array( 'Malawakang_pagbura' ),
);

/** Turkish (Türkçe) */
$specialPageAliases['tr'] = array(
	'Nuke' => array( 'Uçur' ),
);

/** Ukrainian (українська) */
$specialPageAliases['uk'] = array(
	'Nuke' => array( 'Масове_вилучення', 'Множественное_удаление' ),
);

/** Vietnamese (Tiếng Việt) */
$specialPageAliases['vi'] = array(
	'Nuke' => array( 'Xóa_hàng_loạt', 'Xoá_hàng_loạt' ),
);

/** Chinese (中文) */
$specialPageAliases['zh'] = array(
	'Nuke' => array( '大量删除', '大量刪除' ),
);

/** Simplified Chinese (中文（简体）‎) */
$specialPageAliases['zh-hans'] = array(
	'Nuke' => array( '大量删除' ),
);

/** Traditional Chinese (中文（繁體）‎) */
$specialPageAliases['zh-hant'] = array(
	'Nuke' => array( '大量刪除' ),
);
